pub struct Problem {
pub summary: ProblemSummary,
pub statement: Box<str>,
pub input_format: Box<str>,
pub output_format: Box<str>,
pub languages: Vec<Box<str>>,
pub starters: Vec<Starter>,
pub samples: Vec<Sample>,
pub has_public_test_cases: bool,
}Fields
summary: ProblemSummarystatement: Box<str>Public HackerRank source text, which callers must render as untrusted Markdown-like content
input_format: Box<str>Public HackerRank source text, which callers must render as untrusted Markdown-like content
output_format: Box<str>Public HackerRank source text, which callers must render as untrusted Markdown-like content
languages: Vec<Box<str>>Supported HackerRank language keys
starters: Vec<Starter>Public starter source supplied by HackerRank for a language
samples: Vec<Sample>Public sample input/output pairs when HackerRank includes them
has_public_test_cases: boolWhether HackerRank marks the challenge test cases as public